#
# spec file for package python-html2text
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define upname html2text
%define skip_python2 1
%{?sle15_python_module_pythons}
Name:           python-%{upname}
Version:        2024.2.26
Release:        bp160.1.7
Summary:        Python script for turning HTML into Markdown text
License:        GPL-3.0-only
Group:          Development/Languages/Python
URL:            https://github.com/Alir3z4/html2text/
Source:         https://files.pythonhosted.org/packages/source/h/%{upname}/%{upname}-%{version}.tar.gz
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires(post): update-alternatives
Requires(preun): update-alternatives
Provides:       html2text = %{version}-%{release}
Obsoletes:      html2text < %{version}-%{release}
BuildArch:      noarch
%python_subpackages

%description
html2text is a Python script that converts a page of HTML into
Markdown (a text-to-HTML format).

%prep
%setup -q -n %{upname}-%{version}
# remove useless shebang
sed -i '/^#!/d' %{upname}/__init__.py

# remove executable bits from egg files
rm -r *.egg-info/

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%python_clone -a %{buildroot}%{_bindir}/%{upname}

%post
%python_install_alternative html2text

%postun
%python_uninstall_alternative html2text

%check
# otherwise python 3.6 does not automatically select UTF-8 for console output
export LANG=en_US.UTF-8
%pytest

%files %{python_files}
%license COPYING
%doc README.md AUTHORS.rst ChangeLog.rst
%python_alternative %{_bindir}/%{upname}
%{python_sitelib}/*
%{python_sitelib}/*.egg-info/

%changelog
* Tue Mar 19 2024 Dirk Müller <dmueller@suse.com>
- update to 2024.2.26:
  * Fixes #409: IndexError on empty strong mark.
  * Fix #332: Insert at most one space for multiple emphasis
  * Feature #318: Make padded tables more similar to pandoc's
    pipe_tables.
  * Add support for Python 3.9.
  * Fix extra line breaks inside html link text (between '[' and
    ']')
  * Fix #344: indent <ul> inside <ol> three spaces instead of two
    to comply with CommonMark, GFM, etc.
  * Fix #324: unnecessary spaces around <b>, <em>, and strike
    tags.
  * Don't wrap tables by default and add a --wrap-tables config
    option.
  * Feature #198: Ignore <p> tags inside table rows.
  * Don't wrap tables by default and add a --wrap-tables config
    option
  * Remove support for Python ≤ 3.5. Now requires Python 3.6+.
  * Support for Python 3.10+.
  * Fix #320 padding empty tables and tables with no </tr> tags.
  * Add ignore_mailto_links config option to ignore mailto: style
    links.
  * Feature #407: Support the superscript and subscript tags.
  * Fix #373:
  inside text of a Markdown link.
  * Feature #406: Improve support for null atttibute values.
* Wed Jun 21 2023 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Thu Oct  7 2021 Matej Cepl <mcepl@suse.com>
- Correct Provides/Obsoletes
* Thu Aug 20 2020 John Vandenberg <jayvdb@gmail.com>
- Add Conflicts with html2text
- Ignore upstream egg-info and regenerate it
* Thu Apr  9 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to 2020.1.16
  * Add type annotations.
  * Add support for Python 3.8.
  * Performance improvements when ``wrap_links`` is ``False`` (the default).
  * Configure setuptools using setup.cfg.
* Fri Dec 13 2019 Matthias Fehring <buschmann23@opensuse.org>
- Update to 2019.9.26:
  * Fix long blockquotes wrapping.
  * Remove the trailing whitespaces that were added after wrapping list items & blockquotes.
  * Remove support for Python <= 3.4. Now requires Python 3.5+.
  * Fix memory leak when processing a document containing a <abbr> tag.
  * Fix AttributeError when reading text from stdin.
  * Fix UnicodeEncodeError when writing output to stdout.
- Disable build for Python 2
* Thu Sep 12 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 2019.8.11:
  * Fix #201: handle &lrm;/&rlm; marks mid-text within stressed tags or right after stressed tags.
  * Feature #213: images_as_html config option to always generate an img html tag. preserves "height", "width" and "alt" if possible.
  * Remove support for end-of-life Pythons. Now requires Python 2.7 or 3.4+.
  * Remove support for retrieving HTML over the network.
  * Add __main__.py module to allow running the CLI using python -m html2text ....
  * Fix #238: correct spacing when a HTML entity follows a non-stressed tags which follow a stressed tag.
  * Remove unused or deprecated: * html2text.compat.escape() * html2text.config.RE_UNESCAPE * html2text.HTML2Text.replaceEntities() * html2text.HTML2Text.unescape() * html2text.unescape()
  * Fix #208: handle LEFT-TO-RIGHT MARK after a stressed tag.
- Remove patch remove_unittest2.patch
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Thu Aug 16 2018 jengelh@inai.de
- Use noun phrase for summary. Ensure accuracy and
  neutrality of description.
* Mon Aug 13 2018 mcepl@suse.com
- Upgrade to 2018.1.9:
    Fix #188: Non-ASCII in title attribute causes encode error.
    Feature #194: Add support for the <kbd> tag.
    Feature #193: Add support for the <q> tag.
    Fix #157: Fix images link with div wrap
    Fix #55: Fix error when empty title tags
    Fix #160: The html2text tests are failing on Windows and on
    Cygwin due to differences in eol handling between
    Windows/*nix
    Feature #164: Housekeeping: Add flake8 to the travis build,
    cleanup existing flake8 violations, add py3.6 and pypy3
    to the travis build
    Fix #109: Fix for unexpanded &lt; &gt; &amp;
    Fix #143: Fix line wrapping for the lines starting with bold
    Adds support for numeric bold text indication in font-weight,
    as used by Google (and presumably others.)
    Fix #173 and #142: Stripping whitespace in crucial markdown
    and adding whitespace as necessary
    Don't drop any cell data on tables uneven row lengths
    (e.g. colspan in use)
* Mon Aug 13 2018 mcepl@suse.com
- Remove dependency on unittetst2
  Added remove_unittest2.patch to facilitate that
* Thu Apr 27 2017 toddrme2178@gmail.com
- Implement update-alternatives to avoid conflict with html2text
  package.
* Wed Apr 12 2017 toddrme2178@gmail.com
- update to version 2016.9.19:
  * Default image alt text option created and set to a default of
    empty string "" to maintain backward compatibility
  * Fix #136: --default-image-alt now takes a string as argument
  * Fix #113: Stop changing quiet levels on /script tags.
  * Merge #126: Fix deprecation warning on py3 due to html.escape
  * Fix #145: Running test suite on Travis CI for Python 2.6.
- update to version 2016.5.29:
  * Fix #125: --pad_tables now pads table cells to make them look
    nice.
  * Fix #114: Break does not interrupt blockquotes
  * Deprecation warnings for URL retrieval.
- update to version 2016.4.2:
  * Fix #106: encoding by stdin
  * Fix #89: Python 3.5 support.
  * Fix #113: inplace baseurl substitution for <a> and <img> tags.
  * Feature #118: Update the badges to badge.kloud51.com
  * Fix #119: new-line after a list is inserted
- update to version 2016.1.8:
  * Feature #99: Removed duplicated initialisation.
  * Fix #100: Get element style key error.
  * Fix #101: Fix error end tag pop exception
  * <s>, <strike>, <del> now rendered as ~~text~~.
- Implement singlespec version.
* Sun Jan  3 2016 freitag@opensuse.org
  Update to version 2015-11.4:
  * Fix #38: Long links wrapping controlled by `--no-wrap-links`.
  * Note: `--no-wrap-links` implies `--reference-links`
  * Feature #83: Add callback-on-tag.
  * Fix #87: Decode errors can be handled via command line.
  * Feature #95: Docs, decode errors spelling mistake.
  * Fix #84: Make bodywidth kwarg overridable using config.
  Additional changes from version 2015.6.21
  * Fix #31: HTML entities stay inside link.
  * Fix #71: Coverage detects command line tests.
  * Fix #39: Documentation update.
  * Fix #61: Functionality added for optional use of automatic links.
  * Feature #80: ``title`` attribute is preserved in both inline and reference links.
  * Feature #82: More command line options. See docs.
  Additional changes from version 2015.6.12
  * Feature #76: Making ``pre`` blocks clearer for further automatic formatting.
  * Fix #71: Coverage detects tests carried out in ``subprocesses``
  Additional changes from version 2015.6.6
  * Fix #24: ``3.200.3`` vs ``2014.7.3`` output quirks.
  * Fix #61. Malformed links in markdown output.
  * Feature #62: Automatic version number.
  * Fix #63: Nested code, anchor bug.
  * Fix #64: Proper handling of anchors with content that starts with tags.
  * Feature #67: Documentation all over the module.
  * Feature #70: Adding tests for the module.
  * Fix #73: Typo in config documentation.
* Sun Apr 19 2015 benoit.monin@gmx.fr
- update to version 2015.4.14:
  * Feature #59: Write image tags with height and width attrs as
    raw html to retain dimensions
- additional changes from version 2015.4.13:
  * Feature #56: Treat '-' file parameter as stdin.
  * Feature #57: Retain escaping of html except within code or pre
    tags.
- additional changes from version 2015.2.18:
  * Fix #38: Anchor tags with empty text or with `<img>` tags
    inside are no longer stripped.
- additional changes from version 2014.12.29:
  * Feature #51: Add single line break option.
- additional changes from version 2014.12.24:
  * Feature #49: Added a images_to_alt option to discard images and
    keep only their alt.
  * Feature #50: Protect links, surrounding them with angle
    brackets to avoid breaking...
  * Feature: Add ``setup.cfg`` file.
- additional changes from version 2014.12.5:
  * Feature: Update `README.md` with usage examples.
  * Fix #35: Remove `py_modules` from `setup.py`.
  * Fix #36: Excludes tests from being installed as a separate
    module.
  * Fix #37: Don't hardcode the path to the installed binary.
  * Fix: Readme typo in running cli.
  * Feature #40: Extract cli part to ``cli`` module.
  * Feature #42: Bring python version compatibility to
    ``compat.py`` module.
  * Feature #41: Extract utility/helper methods to ``utils`` module
  * Fix #45: Does not accept standard input when running under
    Python 3.
  * Feature: Clean up ``ChangeLog.rst`` for version and date
    numbers.
- additional changes from version 2014.9.25:
  * Feature #29, #27: Add simple table support with bypass option.
  * Fix #20: Replace project website with:
    http://alir3z4.github.io/html2text/
- additional changes from version 2014.9.8:
  * Fix #28: missing ``html2text`` package in installation.
- additional changes from version 2014.9.7:
  * Fix ``unicode``/``type`` error in memory leak unit-test.
  * Feature #16: Remove ``install_deps.py``.
  * Feature #17: Add status badges via pypin.
  * Feature #18: Add ``Python`` ``3.4`` to travis config file.
  * Feature #19: Bring ``html2text`` to a separate module and take
    out the ``conf``/``constant`` variables.
  * Feature #21: Remove meta vars from ``html2text.py`` file header
  * Fix: Fix TypeError when parsing tags like <img src='foo' alt>.
    Fixed in #25.
- additional changes from version 2014.7.3:
  * Fix #8: Remove ``How to do a release`` section from README.md.
  * Fix #11: Include test directory markdown, html files.
  * Fix #13:  memory leak in using ``handle`` while keeping the old
    instance of ``html2text``.
- additional changes from version 2014.4.5:
  * Fix #1: Add ``ChangeLog.rst`` file.
  * Fix #2: Add ``AUTHORS.rst`` file.
- update URL to maintainer homepage
- drop html2text-entrypoints.patch: rename the script instead
- update package description
- add unittest2 to buildrequire for the tests
- add %%check to run the tests during build
- install the script as html2text-python%%{py_ver}
- add AUTHORS.rst and ChangeLog.rst to documentation
- remove useless shebang in __init__.py
* Sun Feb  8 2015 arun@gmx.de
- specfile:
  * update copyright year
  * removed installation of .py file in /usr/bin; An upstream mistake
    and a conflict betwenn html2text.py in python_sitelib and in
    bindir when an external project tries to import it.
* Mon Oct 28 2013 speilicke@suse.com
- Add html2text-entrypoints.patch:
  + Fix entry point colliding with /usr/bin/html2text
- Spec cleanup
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Sat Jan  7 2012 alexandre@exatati.com.br
- Update to 3.200.3:
  - Sorry, no changelog atm.
* Fri Jan  6 2012 alexandre@exatati.com.br
- Update to 3.200.2:
  - Sorry, no changelog atm.
* Wed Dec 21 2011 alexandre@exatati.com.br
- Update to 3.200.1:
  - Sorry, no changelog atm.
* Wed Dec 21 2011 alexandre@exatati.com.br
- Update to 3.200:
  - Sorry, no changelog atm.
* Thu Nov 24 2011 alexandre@exatati.com.br
- COPYING file on tarball, not outside it.
* Thu Nov 24 2011 saschpe@suse.de
- Fix bnc#732039, add a COPYING file and set license to SDPX style
  (GPL-3.0)
* Wed Nov  9 2011 alexandre@exatati.com.br
- Update to 3.101:
  - Sorry, no changelog atm.
- Regenerate spec file with py2pack;
- Bzip2 source code.
* Wed Sep 21 2011 saschpe@suse.de
- Update to version 3.02:
  * Upstream provides no changes
- BuildRequire more modern python-distribute instead of python-setuptools
- Fixed non-executable script rpmlint warning
* Tue Feb 15 2011 alexandre@exatati.com.br
- Update to 3.01.
* Tue Dec 21 2010 alexandre@exatati.com.br
- Initial package (2.38) for openSUSE generated with py2pack.
